@@ -734,6 +734,14 @@
  */
 #define UC_BUFFER_LEN \
 	1024
+/**
+ * UC_BUFFER_DATETIME_LEN:
+ *
+ * Macro to indicate maximum length of date and time buffers.
+ */
+#define UC_BUFFER_DATETIME_LEN \
+	20
+
 /**
  * UC_BUFFER_DATE_LEN:
  *
@@ -741,6 +749,7 @@
  */
 #define UC_BUFFER_DATE_LEN \
 	11
+
 /**
  * UC_HEADER_STATUS_CODE_LEN:
  *
