@@ -408,14 +408,16 @@ uc_utils_get_auth_fields (GladeXML * g,
   gboolean ret = FALSE;
 
   /* get user */
-  if ((text = (gchar *) gtk_entry_get_text (GTK_ENTRY (w_auth_user))))
+  if (strlen (
+        text = (gchar *) gtk_entry_get_text (GTK_ENTRY (w_auth_user))))
     {
       g_strstrip (text);
       if (strlen (text))
 	*auth_user = text;
     }
   /* get password */
-  if ((text = (gchar *) gtk_entry_get_text (GTK_ENTRY (w_auth_password))))
+  if (strlen (
+        text = (gchar *) gtk_entry_get_text (GTK_ENTRY (w_auth_password))))
     {
       g_strstrip (text);
       if (strlen (text))
@@ -646,60 +648,29 @@ uc_utils_debug_dump_link_properties (const UCLinkProperties * prop)
 	   "	bad_extensions: %u\n"
 	   "	virii: %u\n"
 	   "	w3c_valid: %u\n",
-	   prop->
-	   uid,
-	   prop->
-	   current_path,
-	   prop->
-	   link_type,
-	   prop->
-	   link_value,
-	   prop->
-	   url,
-	   prop->
-	   normalized_url,
-	   prop->
-	   label,
-	   prop->
-	   protocol,
-	   prop->
-	   h_name,
-	   prop->
-	   port,
-	   prop->
-	   path,
-	   prop->
-	   args,
-	   prop->
-	   domain,
-	   prop->
-	   header_size,
-	   prop->
-	   depth_level,
-	   prop->
-	   is_parsable,
-	   prop->
-	   is_downloadable,
-	   prop->
-	   checked,
-	   prop->
-	   to_delete,
-	   (prop->
-	    metas
-	    !=
-	    NULL),
-	   (prop->
-	    emails
-	    !=
-	    NULL),
-	   (prop->
-	    childs
-	    !=
-	    NULL),
-	   (prop->
-	    similar_links_parents
-	    !=
-	    NULL),
+	   prop->uid,
+	   prop->current_path,
+	   prop->link_type,
+	   prop->link_value,
+	   prop->url,
+	   prop->normalized_url,
+	   prop->label,
+	   prop->protocol,
+	   prop->h_name,
+	   prop->port,
+	   prop-> path,
+	   prop-> args,
+	   prop-> domain,
+	   prop-> header_size,
+	   prop-> depth_level,
+	   prop-> is_parsable,
+	   prop-> is_downloadable,
+	   prop-> checked,
+	   prop-> to_delete,
+	   (prop-> metas != NULL),
+	   (prop-> emails != NULL),
+	   (prop-> childs != NULL),
+	   (prop-> similar_links_parents != NULL),
 	   (prop->bad_extensions != NULL), prop->virii, prop->w3c_valid);
 }
 
