@@ -780,6 +780,19 @@ uc_web_site_begin_check (void)
   UC_GET_WIDGET ("urls_list", WGET ("main_window"), widget);
   treeview = GTK_TREE_VIEW (widget);
 
+  treestore = gtk_tree_store_new (N_COLUMNS,
+				  G_TYPE_INT,
+				  GDK_TYPE_PIXBUF,
+				  GDK_TYPE_PIXBUF,
+				  GDK_TYPE_PIXBUF,
+				  GDK_TYPE_PIXBUF,
+				  G_TYPE_STRING,
+				  G_TYPE_STRING,
+				  G_TYPE_STRING, G_TYPE_STRING);
+
+  uc_application_build_url_treeview ();
+  gtk_widget_show (widget);
+
   /* set general project settings */
   tmp = uc_url_get_hostname (NULL, uc_project_get_url ());
   uc_project_set_current_host (tmp);
@@ -837,10 +850,12 @@ uc_web_site_begin_check (void)
 
       /* retreive project's pages */
       uc_project_set_check_is_current (TRUE);
+      uc_project_set_check_is_main (TRUE);
       prop->normalized_url =
 	uc_url_normalize (uc_project_get_current_host (), "", tag->value);
       uc_lists_already_checked_links_append (prop->normalized_url, prop);
       list = uc_web_site_url_get_links (prop, 0);
+      uc_project_set_check_is_main (FALSE);
       uc_project_set_check_is_current (FALSE);
 
       /* if there is some result, display it in the main
@@ -852,18 +867,9 @@ uc_web_site_begin_check (void)
 	list = g_list_prepend (list, prop);
 	uc_lists_checked_links_set (list);
 
-	treestore = gtk_tree_store_new (N_COLUMNS,
-					G_TYPE_INT,
-					GDK_TYPE_PIXBUF,
-					GDK_TYPE_PIXBUF,
-					GDK_TYPE_PIXBUF,
-					GDK_TYPE_PIXBUF,
-					G_TYPE_STRING,
-					G_TYPE_STRING, G_TYPE_STRING);
-
 	/* display main tree view */
+	gtk_tree_store_clear (treestore);
 	uc_check_display_list (uc_lists_checked_links_get (), NULL);
-	uc_application_build_url_treeview ();
 
 	/* update application menu */
 	WSENS ("mwm_display", TRUE);
